<?xml version="1.0" encoding="UTF-8" ?>
<!-- $Id: amstex-to-bibliography.xsl 1164 2009-01-04 20:07:26Z michalr $ -->
<xsl:transform xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" 
               xmlns:str="http://exslt.org/strings">
    
    <!-- Output setup. -->
    <xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
    
    <!-- Math expressions conversion. -->
    <xsl:template match="texmath">
        <xsl:if test="@type='inline'">$<xsl:value-of select="."/>$</xsl:if>
        <xsl:if test="@type='display'">\[<xsl:value-of select="."/>\]</xsl:if>
    </xsl:template>
    
    <!-- References extraction. -->
    <xsl:template match="/">
        <references>
            <xsl:apply-templates select="//Refs/ref">
                <xsl:sort select="./reference/@id"/>
            </xsl:apply-templates>
        </references>
    </xsl:template>
    
    <!-- Bibliography entry extraction. -->
    <xsl:template match="Refs/ref">
        <reference>
            <xsl:attribute name="id">
                <xsl:value-of select="position()"/>
            </xsl:attribute>
            <xsl:if test="./key">
                <prefix>
                    <xsl:apply-templates select="./key"/>
                </prefix>
            </xsl:if>
            <xsl:if test="./paper">
                <paper>
                    <xsl:apply-templates select="./paper"/>
                </paper>
            </xsl:if>
            <xsl:if test="./book">
                <book>
                    <xsl:apply-templates select="./book"/>
                </book>
            </xsl:if>
            <xsl:if test="./by">
                <authors>
                    <xsl:apply-templates select="./by"/>
                </authors>
            </xsl:if>
            <xsl:if test="./bysame">
                <authors>
                    <xsl:apply-templates select="./preceding::by[1]"/>
                </authors>
            </xsl:if>
            <xsl:if test="./ed">
                <editor>
                    <xsl:apply-templates select="./ed"/>
                </editor>
            </xsl:if>
            <xsl:if test="./eds">
                <editors>
                    <xsl:apply-templates select="./eds"/>
                </editors>
            </xsl:if>
            <xsl:if test="./publaddr">
                <address>
                    <xsl:apply-templates select="./publaddr"/>
                </address>
            </xsl:if>
            <xsl:if test="./jour">
                <journal>
                    <xsl:apply-templates select="./jour"/>
                </journal>
            </xsl:if>
            <xsl:if test="./issue">
                <number>
                    <xsl:apply-templates select="./issue"/>
                </number>
            </xsl:if>
            <xsl:if test="./publ">
                <publisher>
                    <xsl:apply-templates select="./publ"/>
                </publisher>
            </xsl:if>
            <xsl:if test="./vol">
                <volume>
                    <xsl:apply-templates select="./vol"/>
                </volume>
            </xsl:if>
            <xsl:if test="./yr">
                <year>
                    <xsl:apply-templates select="./yr"/>
                </year>
            </xsl:if>
            <xsl:if test="./toappear">
                <to-appear/>
            </xsl:if>
            <xsl:if test="./page">
                <page>
                    <xsl:apply-templates select="./page"/>
                </page>
            </xsl:if>
            <xsl:if test="./pages">
                <pages>
                    <xsl:apply-templates select="./pages"/>
                </pages>
            </xsl:if>
            <xsl:if test="./inbook">
                <in-book>
                    <xsl:apply-templates select="./inbook"/>
                </in-book>
            </xsl:if>
            <xsl:if test="./lang">
                <language>
                    <xsl:apply-templates select="./lang"/>
                </language>
            </xsl:if>
            <xsl:if test="./transl">
                <translation-info>
                    <xsl:apply-templates select="./transl"/>
                </translation-info>
            </xsl:if>
            <xsl:if test="./bookinfo">
                <book-info>
                    <xsl:apply-templates select="./bookinfo"/>
                </book-info>
            </xsl:if>
            <xsl:if test="./procinfo">
                <proceedings-info>
                    <xsl:apply-templates select="./procinfo"/>
                </proceedings-info>
            </xsl:if>
            <xsl:if test="./finalinfo">
                <final-info>
                    <xsl:apply-templates select="./finalinfo"/>
                </final-info>
            </xsl:if>
            <xsl:if test="./miscnote">
                <miscellaneous-note>
                    <xsl:apply-templates select="./miscnote"/>
                </miscellaneous-note>
            </xsl:if>
            <xsl:if test="./paperinfo">
                <paper-info>
                    <xsl:apply-templates select="./paperinfo"/>
                </paper-info>
            </xsl:if>
            <xsl:if test="./ZBL">
                <ZBL>
                    <xsl:apply-templates select="./ZBL"/>
                </ZBL>
            </xsl:if>
            <xsl:if test="./moreref">
                <xsl:for-each select="./moreref">
                    <additional-reference>
                        <xsl:apply-templates select="./*"/>
                    </additional-reference>
                </xsl:for-each>
            </xsl:if>
        </reference>
    </xsl:template>
    
    <!-- Substitute new-line charecters for spaces. -->
    <xsl:template match="text()">
        <xsl:value-of select="translate(.,'&#10;',' ')"/>
    </xsl:template>
    
</xsl:transform>
