<?xml version="1.0" encoding="UTF-8" ?>
<!-- $Id: bibliography-to-dmlcz-references.xsl 1164 2009-01-04 20:07:26Z michalr $ -->
<xsl:transform xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" 
               xmlns:str="http://exslt.org/strings">
    
    <!-- Output setup. -->
    <xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
    
    <!-- References extraction. -->
    <xsl:template match="/">
        <references>
            <xsl:apply-templates select="/references/reference">
                <xsl:sort select="./reference/@id"/>
            </xsl:apply-templates>
        </references>
    </xsl:template>
    
    <!-- Bibliography entry extraction. -->
    <xsl:template match="/references/reference">
        <reference>
            <xsl:attribute name="id">
                <xsl:value-of select="normalize-space(./@id)"/>
            </xsl:attribute>
            <xsl:if test="./prefix">
                <prefix>
                    <xsl:text>[</xsl:text>
                    <xsl:value-of select="normalize-space(./prefix)"/>
                    <xsl:text>]</xsl:text>
                </prefix>
            </xsl:if>
            <xsl:if test="./paper">
                <title>
                    <xsl:value-of select="normalize-space(./paper)"/>
                </title>
            </xsl:if>
            <xsl:if test="./book">
                <title>
                    <xsl:value-of select="normalize-space(./book)"/>
                </title>
            </xsl:if>
            <xsl:if test="./authors">
                <authors>
                    <xsl:value-of select="normalize-space(./authors)"/>
                </authors>
            </xsl:if>
            <xsl:if test="./editor">
                <editors>
                    <xsl:value-of select="normalize-space(./editor)"/>
                </editors>
            </xsl:if>
            <xsl:if test="./editors">
                <editors>
                    <xsl:value-of select="normalize-space(./editors)"/>
                </editors>
            </xsl:if>
            <xsl:if test="./address">
                <address>
                    <xsl:value-of select="normalize-space(./address)"/>
                </address>
            </xsl:if>
            <xsl:if test="./journal">
                <journal>
                    <xsl:value-of select="normalize-space(./journal)"/>
                </journal>
            </xsl:if>
            <xsl:if test="./number">
                <number>
                    <xsl:value-of select="normalize-space(./number)"/>
                </number>
            </xsl:if>
            <xsl:if test="./publisher">
                <publisher>
                    <xsl:value-of select="normalize-space(./publisher)"/>
                </publisher>
            </xsl:if>
            <xsl:if test="./volume">
                <volume>
                    <xsl:value-of select="normalize-space(./volume)"/>
                </volume>
            </xsl:if>
            <xsl:if test="./year">
                <year>
                    <xsl:value-of select="normalize-space(./year)"/>
                </year>
            </xsl:if>
            <xsl:if test="./to-appear">
                <year>
                    <xsl:text>to appear</xsl:text>
                </year>
            </xsl:if>
            <xsl:if test="./page">
                <page>
                    <xsl:value-of select="normalize-space(./page)"/>
                </page>
            </xsl:if>
            <xsl:if test="./pages">
                <pages>
                    <xsl:value-of select="normalize-space(./pages)"/>
                </pages>
            </xsl:if>
            <xsl:if test="./in-book">
                <in-book>
                    <xsl:value-of select="normalize-space(./in-book)"/>
                </in-book>
            </xsl:if>
            <xsl:if test="./language">
                <language>
                    <xsl:value-of select="normalize-space(./language)"/>
                </language>
            </xsl:if>
            <xsl:if test="./translation-info">
                <translation-info>
                    <xsl:value-of select="normalize-space(./translation-info)"/>
                </translation-info>
            </xsl:if>
            <xsl:if test="./book-info">
                <book-info>
                    <xsl:value-of select="normalize-space(./book-info)"/>
                </book-info>
            </xsl:if>
            <xsl:if test="./proceedings-info">
                <proceedings-info>
                    <xsl:value-of select="normalize-space(./proceedings-info)"/>
                </proceedings-info>
            </xsl:if>
            <xsl:if test="./final-info">
                <final-info>
                    <xsl:value-of select="normalize-space(./final-info)"/>
                </final-info>
            </xsl:if>
            <xsl:if test="./miscellaneous-note">
                <miscellaneous-note>
                    <xsl:value-of select="normalize-space(./miscellaneous-note)"/>
                </miscellaneous-note>
            </xsl:if>
            <xsl:if test="./paper-info">
                <paper-info>
                    <xsl:value-of select="normalize-space(./paper-info)"/>
                </paper-info>
            </xsl:if>
            <xsl:if test="./ZBL">
                <ZBL>
                    <xsl:value-of select="normalize-space(./ZBL)"/>
                </ZBL>
            </xsl:if>
            <xsl:if test="./additional-reference">
                <xsl:for-each select="./additional-reference">
                <additional-reference>
                    <xsl:value-of select="normalize-space(.)"/>
                </additional-reference>
                </xsl:for-each>
            </xsl:if>
            <suffix>
                <xsl:choose>
                    <xsl:when test="./book">
                        <xsl:if test="./book-info">
                            <xsl:value-of select="normalize-space(./book-info)"/>
                        </xsl:if>
                        <xsl:if test="./proceedings-info">
                            <xsl:if test="./book-info">
                                <xsl:text> </xsl:text>    
                            </xsl:if>
                            <xsl:text>(</xsl:text>
                            <xsl:value-of select="normalize-space(./proceedings-info)"/>
                            <xsl:text>)</xsl:text>
                        </xsl:if>
                        <xsl:if test="./volume">
                            <xsl:if test="./book-info or ./proceedings-info">
                                <xsl:text>, </xsl:text>
                            </xsl:if>
                            <xsl:text>vol. </xsl:text>
                            <xsl:value-of select="normalize-space(./volume)"/>
                        </xsl:if>
                        <xsl:if test="./editor or ./editors">
                            <xsl:if test="./book-info or ./proceedings-info or ./volume">
                                <xsl:text>, </xsl:text>
                            </xsl:if>
                            <xsl:if test="./editor">
                                <xsl:value-of select="normalize-space(./editor)"/>
                                <xsl:text> (ed.)</xsl:text>
                            </xsl:if>
                            <xsl:if test="./editors">
                                <xsl:value-of select="normalize-space(./editors)"/>
                                <xsl:text> (eds.)</xsl:text>
                            </xsl:if>
                        </xsl:if>
                        <xsl:if test="./publisher">
                            <xsl:if test="./book-info or ./proceedings-info or ./volume or ./editor or ./editors">
                                <xsl:text>, </xsl:text>
                            </xsl:if>
                            <xsl:value-of select="normalize-space(./publisher)"/>
                        </xsl:if>
                        <xsl:if test="./address">
                            <xsl:if test="./book-info or ./proceedings-info or ./volume or ./editor or ./editors or ./publisher">
                                <xsl:text>, </xsl:text>
                            </xsl:if>
                            <xsl:value-of select="normalize-space(./address)"/>
                        </xsl:if>
                        <xsl:if test="./year">
                            <xsl:if test="./book-info or ./proceedings-info or ./volume or ./editor or ./editors or ./publisher or ./address">
                                <xsl:text>, </xsl:text>
                            </xsl:if>
                            <xsl:value-of select="normalize-space(./year)"/>
                        </xsl:if>
                        <xsl:if test="./to-appear">
                            <xsl:if test="./book-info or ./proceedings-info or ./volume or ./editor or ./editors or ./publisher or ./address or ./year">
                                <xsl:text>, </xsl:text>
                            </xsl:if>
                            <xsl:text>to appear</xsl:text>
                        </xsl:if>
                        <xsl:if test="./page or ./pages">
                            <xsl:if test="./book-info or ./proceedings-info or ./volume or ./editor or ./editors or ./publisher or ./address or ./year or ./to-appear">
                                <xsl:text>, </xsl:text>
                            </xsl:if>
                            <xsl:if test="./page">
                                <xsl:text>p. </xsl:text>
                                <xsl:value-of select="normalize-space(./page)"/>
                            </xsl:if>
                            <xsl:if test="./pages">
                                <xsl:text>pp. </xsl:text>
                                <xsl:value-of select="normalize-space(./pages)"/>
                            </xsl:if>
                        </xsl:if>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:if test="./paper-info">
                            <xsl:value-of select="normalize-space(./paper-info)"/>
                        </xsl:if>
                        <xsl:choose>
                            <xsl:when test="./in-book">
                                <xsl:if test="./in-book">
                                    <xsl:if test="./paper-info">
                                        <xsl:text>, </xsl:text>
                                    </xsl:if>
                                    <xsl:value-of select="normalize-space(./in-book)"/>
                                </xsl:if>
                                <xsl:if test="./proceedings-info">
                                    <xsl:if test="./paper-info or ./in-book">
                                        <xsl:text> </xsl:text>
                                    </xsl:if>
                                    <xsl:text>(</xsl:text>
                                    <xsl:value-of select="normalize-space(./proceedings-info)"/>
                                    <xsl:text>)</xsl:text>
                                </xsl:if>
                                <xsl:if test="./editor or ./editors">
                                    <xsl:if test="./paper-info or ./in-book or ./proceedings-info">
                                        <xsl:text>, </xsl:text>
                                    </xsl:if>
                                    <xsl:if test="./editor">
                                        <xsl:value-of select="normalize-space(./editor)"/>
                                        <xsl:text> (ed.)</xsl:text>
                                    </xsl:if>
                                    <xsl:if test="./editors">
                                        <xsl:value-of select="normalize-space(./editors)"/>
                                        <xsl:text> (eds.)</xsl:text>
                                    </xsl:if>
                                </xsl:if>
                                <xsl:if test="./book-info">
                                    <xsl:if test="./paper-info or ./in-book or ./proceedings-info or ./editor or ./editors">
                                        <xsl:text>, </xsl:text>
                                    </xsl:if>
                                    <xsl:value-of select="normalize-space(./book-info)"/>
                                </xsl:if>
                                <xsl:if test="./volume">
                                    <xsl:if test="./paper-info or ./in-book or ./proceedings-info or ./editor or ./editors or ./book-info">
                                        <xsl:text> </xsl:text>    
                                    </xsl:if>
                                    <xsl:text>vol. </xsl:text>
                                    <xsl:value-of select="normalize-space(./volume)"/>
                                </xsl:if>
                                <xsl:if test="./publisher">
                                    <xsl:if test="./paper-info or ./in-book or ./proceedings-info or ./editor or ./editors or ./book-info or ./volume">
                                        <xsl:text>, </xsl:text>
                                    </xsl:if>
                                    <xsl:value-of select="normalize-space(./publisher)"/>
                                </xsl:if>
                                <xsl:if test="./address">
                                    <xsl:if test="./paper-info or ./in-book or ./proceedings-info or ./editor or ./editors or ./book-info or ./volume or ./publisher">
                                        <xsl:text>, </xsl:text>
                                    </xsl:if>
                                    <xsl:value-of select="normalize-space(./address)"/>
                                </xsl:if>
                                <xsl:if test="./year">
                                    <xsl:if test="./paper-info or ./in-book or ./proceedings-info or ./editor or ./editors or ./book-info or ./volume or ./publisher or ./address">
                                        <xsl:text>, </xsl:text>
                                    </xsl:if>
                                    <xsl:value-of select="normalize-space(./year)"/>
                                </xsl:if>
                                <xsl:if test="./to-appear">
                                    <xsl:if test="./paper-info or ./in-book or ./proceedings-info or ./editor or ./editors or ./book-info or ./volume or ./publisher or ./address or ./year">
                                        <xsl:text>, </xsl:text>    
                                    </xsl:if>
                                    <xsl:text>to appear</xsl:text>
                                </xsl:if>
                                <xsl:if test="./page or ./pages">
                                    <xsl:if test="./paper-info or ./in-book or ./proceedings-info or ./editor or ./editors or ./book-info or ./volume or ./publisher or ./address or ./year or ./to-appear">
                                        <xsl:text>, </xsl:text>    
                                    </xsl:if>
                                    <xsl:if test="./page">
                                        <xsl:text>p. </xsl:text>
                                        <xsl:value-of select="normalize-space(./page)"/>
                                    </xsl:if>
                                    <xsl:if test="./pages">
                                        <xsl:text>pp. </xsl:text>
                                        <xsl:value-of select="normalize-space(./pages)"/>
                                    </xsl:if>
                                </xsl:if>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:if test="./journal">
                                    <xsl:if test="./paper-info">
                                        <xsl:text>, </xsl:text>
                                    </xsl:if>
                                    <xsl:value-of select="normalize-space(./journal)"/>
                                </xsl:if>
                                <xsl:if test="./volume">
                                    <xsl:if test="./paper-info or ./journal">
                                        <xsl:text> </xsl:text>
                                    </xsl:if>
                                    <xsl:value-of select="normalize-space(./volume)"/>
                                </xsl:if>
                                <xsl:if test="./year">
                                    <xsl:if test="./paper-info or ./journal or ./volume">
                                        <xsl:text> </xsl:text>
                                    </xsl:if>
                                    <xsl:text>(</xsl:text>
                                    <xsl:value-of select="normalize-space(./year)"/>
                                    <xsl:text>)</xsl:text>
                                </xsl:if>
                                <xsl:if test="./to-appear">
                                    <xsl:if test="./paper-info or ./journal or ./volume or ./year">
                                        <xsl:text> </xsl:text>
                                    </xsl:if>
                                    <xsl:text>(to appear)</xsl:text>
                                </xsl:if>
                                <xsl:if test="./number">
                                    <xsl:if test="./paper-info or ./journal or ./volume or ./year or ./to-appear">
                                        <xsl:text>, </xsl:text>
                                    </xsl:if>
                                    <xsl:text>no. </xsl:text>
                                    <xsl:value-of select="normalize-space(./number)"/>
                                </xsl:if>
                                <xsl:if test="./publisher">
                                    <xsl:if test="./paper-info or ./journal or ./volume or ./year or ./to-appear or ./number">
                                        <xsl:text>, </xsl:text>
                                    </xsl:if>
                                    <xsl:value-of select="normalize-space(./publisher)"/>
                                </xsl:if>
                                <xsl:if test="./address">
                                    <xsl:if test="./paper-info or ./journal or ./volume or ./year or ./to-appear or ./number or ./publisher">
                                        <xsl:text>, </xsl:text>
                                    </xsl:if>
                                    <xsl:value-of select="normalize-space(./address)"/>
                                </xsl:if>
                                <xsl:if test="./page or ./pages">
                                    <xsl:if test="./paper-info or ./journal or ./volume or ./year or ./to-appear or ./number or ./publisher or ./address">
                                        <xsl:text>, </xsl:text>
                                    </xsl:if>
                                    <xsl:if test="./page">
                                        <xsl:value-of select="normalize-space(./page)"/>
                                    </xsl:if>
                                    <xsl:if test="./pages">
                                        <xsl:value-of select="normalize-space(./pages)"/>
                                    </xsl:if>
                                </xsl:if>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:if test="./final-info">
                    <xsl:if test="./paper-info or ./journal or ./volume or ./year or ./to-appear or ./number or ./publisher or ./address or ./in-book or ./proceedings-info or ./editor or ./editors or ./book-info">
                        <xsl:text>, </xsl:text>
                    </xsl:if>
                    <xsl:value-of select="normalize-space(./final-info)"/>
                </xsl:if>
                <xsl:if test="./miscellaneous-note">
                    <xsl:if test="./paper-info or ./journal or ./volume or ./year or ./to-appear or ./number or ./publisher or ./address or ./in-book or ./proceedings-info or ./editor or ./editors or ./book-info or ./final-info">
                        <xsl:text> </xsl:text>
                    </xsl:if>
                    <xsl:text>(</xsl:text>
                    <xsl:value-of select="normalize-space(./miscellaneous-note)"/>
                    <xsl:text>)</xsl:text>
                </xsl:if>
                <xsl:text>.</xsl:text>
                <xsl:if test="./language">
                    <xsl:if test="./paper-info or ./journal or ./volume or ./year or ./to-appear or ./number or ./publisher or ./address or ./in-book or ./proceedings-info or ./editor or ./editors or ./book-info or ./final-info or ./miscellaneous-note">
                        <xsl:text> </xsl:text>
                    </xsl:if>
                    <xsl:text>(</xsl:text>
                    <xsl:value-of select="normalize-space(./language)"/>
                    <xsl:text>)</xsl:text>
                </xsl:if>
            </suffix>
        </reference>
    </xsl:template>
    
</xsl:transform>
